# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.cloud.recommendationengine_v1beta1.types import common


__protobuf__ = proto.module(
    package="google.cloud.recommendationengine.v1beta1",
    manifest={"CatalogItem", "ProductCatalogItem", "Image",},
)


class CatalogItem(proto.Message):
    r"""CatalogItem captures all metadata information of items to be
    recommended.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        id (str):
            Required. Catalog item identifier. UTF-8
            encoded string with a length limit of 128 bytes.
            This id must be unique among all catalog items
            within the same catalog. It should also be used
            when logging user events in order for the user
            events to be joined with the Catalog.
        category_hierarchies (Sequence[google.cloud.recommendationengine_v1beta1.types.CatalogItem.CategoryHierarchy]):
            Required. Catalog item categories. This field is repeated
            for supporting one catalog item belonging to several
            parallel category hierarchies.

            For example, if a shoes product belongs to both ["Shoes &
            Accessories" -> "Shoes"] and ["Sports & Fitness" ->
            "Athletic Clothing" -> "Shoes"], it could be represented as:

            ::

                 "categoryHierarchies": [
                   { "categories": ["Shoes & Accessories", "Shoes"]},
                   { "categories": ["Sports & Fitness", "Athletic Clothing", "Shoes"] }
                 ]
        title (str):
            Required. Catalog item title. UTF-8 encoded
            string with a length limit of 1 KiB.
        description (str):
            Optional. Catalog item description. UTF-8
            encoded string with a length limit of 5 KiB.
        item_attributes (google.cloud.recommendationengine_v1beta1.types.FeatureMap):
            Optional. Highly encouraged. Extra catalog
            item attributes to be included in the
            recommendation model. For example, for retail
            products, this could include the store name,
            vendor, style, color, etc. These are very strong
            signals for recommendation model, thus we highly
            recommend providing the item attributes here.
        language_code (str):
            Optional. Language of the title/description/item_attributes.
            Use language tags defined by BCP 47.
            https://www.rfc-editor.org/rfc/bcp/bcp47.txt. Our supported
            language codes include 'en', 'es', 'fr', 'de', 'ar', 'fa',
            'zh', 'ja', 'ko', 'sv', 'ro', 'nl'. For other languages,
            contact your Google account manager.
        tags (Sequence[str]):
            Optional. Filtering tags associated with the
            catalog item. Each tag should be a UTF-8 encoded
            string with a length limit of 1 KiB.
            This tag can be used for filtering
            recommendation results by passing the tag as
            part of the predict request filter.
        item_group_id (str):
            Optional. Variant group identifier for prediction results.
            UTF-8 encoded string with a length limit of 128 bytes.

            This field must be enabled before it can be used. `Learn
            more </recommendations-ai/docs/catalog#item-group-id>`__.
        product_metadata (google.cloud.recommendationengine_v1beta1.types.ProductCatalogItem):
            Optional. Metadata specific to retail
            products.
            This field is a member of `oneof`_ ``recommendation_type``.
    """

    class CategoryHierarchy(proto.Message):
        r"""Category represents catalog item category hierarchy.

        Attributes:
            categories (Sequence[str]):
                Required. Catalog item categories. Each
                category should be a UTF-8 encoded string with a
                length limit of 2 KiB.
                Note that the order in the list denotes the
                specificity (from least to most specific).
        """

        categories = proto.RepeatedField(proto.STRING, number=1,)

    id = proto.Field(proto.STRING, number=1,)
    category_hierarchies = proto.RepeatedField(
        proto.MESSAGE, number=2, message=CategoryHierarchy,
    )
    title = proto.Field(proto.STRING, number=3,)
    description = proto.Field(proto.STRING, number=4,)
    item_attributes = proto.Field(proto.MESSAGE, number=5, message=common.FeatureMap,)
    language_code = proto.Field(proto.STRING, number=6,)
    tags = proto.RepeatedField(proto.STRING, number=8,)
    item_group_id = proto.Field(proto.STRING, number=9,)
    product_metadata = proto.Field(
        proto.MESSAGE,
        number=10,
        oneof="recommendation_type",
        message="ProductCatalogItem",
    )


class ProductCatalogItem(proto.Message):
    r"""ProductCatalogItem captures item metadata specific to retail
    products.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        exact_price (google.cloud.recommendationengine_v1beta1.types.ProductCatalogItem.ExactPrice):
            Optional. The exact product price.
            This field is a member of `oneof`_ ``price``.
        price_range (google.cloud.recommendationengine_v1beta1.types.ProductCatalogItem.PriceRange):
            Optional. The product price range.
            This field is a member of `oneof`_ ``price``.
        costs (Sequence[google.cloud.recommendationengine_v1beta1.types.ProductCatalogItem.CostsEntry]):
            Optional. A map to pass the costs associated with the
            product.

            For example: {"manufacturing": 45.5} The profit of selling
            this item is computed like so:

            -  If 'exactPrice' is provided, profit = displayPrice -
               sum(costs)
            -  If 'priceRange' is provided, profit = minPrice -
               sum(costs)
        currency_code (str):
            Optional. Only required if the price is set.
            Currency code for price/costs. Use three-
            character ISO-4217 code.
        stock_state (google.cloud.recommendationengine_v1beta1.types.ProductCatalogItem.StockState):
            Optional. Online stock state of the catalog item. Default is
            ``IN_STOCK``.
        available_quantity (int):
            Optional. The available quantity of the item.
        canonical_product_uri (str):
            Optional. Canonical URL directly linking to
            the item detail page with a length limit of 5
            KiB..
        images (Sequence[google.cloud.recommendationengine_v1beta1.types.Image]):
            Optional. Product images for the catalog
            item.
    """

    class StockState(proto.Enum):
        r"""Item stock state. If this field is unspecified, the item is
        assumed to be in stock.
        """
        _pb_options = {"allow_alias": True}
        STOCK_STATE_UNSPECIFIED = 0
        IN_STOCK = 0
        OUT_OF_STOCK = 1
        PREORDER = 2
        BACKORDER = 3

    class ExactPrice(proto.Message):
        r"""Exact product price.

        Attributes:
            display_price (float):
                Optional. Display price of the product.
            original_price (float):
                Optional. Price of the product without any
                discount. If zero, by default set to be the
                'displayPrice'.
        """

        display_price = proto.Field(proto.FLOAT, number=1,)
        original_price = proto.Field(proto.FLOAT, number=2,)

    class PriceRange(proto.Message):
        r"""Product price range when there are a range of prices for
        different variations of the same product.

        Attributes:
            min_ (float):
                Required. The minimum product price.
            max_ (float):
                Required. The maximum product price.
        """

        min_ = proto.Field(proto.FLOAT, number=1,)
        max_ = proto.Field(proto.FLOAT, number=2,)

    exact_price = proto.Field(
        proto.MESSAGE, number=1, oneof="price", message=ExactPrice,
    )
    price_range = proto.Field(
        proto.MESSAGE, number=2, oneof="price", message=PriceRange,
    )
    costs = proto.MapField(proto.STRING, proto.FLOAT, number=3,)
    currency_code = proto.Field(proto.STRING, number=4,)
    stock_state = proto.Field(proto.ENUM, number=5, enum=StockState,)
    available_quantity = proto.Field(proto.INT64, number=6,)
    canonical_product_uri = proto.Field(proto.STRING, number=7,)
    images = proto.RepeatedField(proto.MESSAGE, number=8, message="Image",)


class Image(proto.Message):
    r"""Catalog item thumbnail/detail image.

    Attributes:
        uri (str):
            Required. URL of the image with a length
            limit of 5 KiB.
        height (int):
            Optional. Height of the image in number of
            pixels.
        width (int):
            Optional. Width of the image in number of
            pixels.
    """

    uri = proto.Field(proto.STRING, number=1,)
    height = proto.Field(proto.INT32, number=2,)
    width = proto.Field(proto.INT32, number=3,)


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from google.cloud.recommendationengine_v1beta1.services.catalog_service.client import (
    CatalogServiceClient,
)
from google.cloud.recommendationengine_v1beta1.services.catalog_service.async_client import (
    CatalogServiceAsyncClient,
)
from google.cloud.recommendationengine_v1beta1.services.prediction_api_key_registry.client import (
    PredictionApiKeyRegistryClient,
)
from google.cloud.recommendationengine_v1beta1.services.prediction_api_key_registry.async_client import (
    PredictionApiKeyRegistryAsyncClient,
)
from google.cloud.recommendationengine_v1beta1.services.prediction_service.client import (
    PredictionServiceClient,
)
from google.cloud.recommendationengine_v1beta1.services.prediction_service.async_client import (
    PredictionServiceAsyncClient,
)
from google.cloud.recommendationengine_v1beta1.services.user_event_service.client import (
    UserEventServiceClient,
)
from google.cloud.recommendationengine_v1beta1.services.user_event_service.async_client import (
    UserEventServiceAsyncClient,
)

from google.cloud.recommendationengine_v1beta1.types.catalog import CatalogItem
from google.cloud.recommendationengine_v1beta1.types.catalog import Image
from google.cloud.recommendationengine_v1beta1.types.catalog import ProductCatalogItem
from google.cloud.recommendationengine_v1beta1.types.catalog_service import (
    CreateCatalogItemRequest,
)
from google.cloud.recommendationengine_v1beta1.types.catalog_service import (
    DeleteCatalogItemRequest,
)
from google.cloud.recommendationengine_v1beta1.types.catalog_service import (
    GetCatalogItemRequest,
)
from google.cloud.recommendationengine_v1beta1.types.catalog_service import (
    ListCatalogItemsRequest,
)
from google.cloud.recommendationengine_v1beta1.types.catalog_service import (
    ListCatalogItemsResponse,
)
from google.cloud.recommendationengine_v1beta1.types.catalog_service import (
    UpdateCatalogItemRequest,
)
from google.cloud.recommendationengine_v1beta1.types.common import FeatureMap
from google.cloud.recommendationengine_v1beta1.types.import_ import CatalogInlineSource
from google.cloud.recommendationengine_v1beta1.types.import_ import GcsSource
from google.cloud.recommendationengine_v1beta1.types.import_ import (
    ImportCatalogItemsRequest,
)
from google.cloud.recommendationengine_v1beta1.types.import_ import (
    ImportCatalogItemsResponse,
)
from google.cloud.recommendationengine_v1beta1.types.import_ import ImportErrorsConfig
from google.cloud.recommendationengine_v1beta1.types.import_ import ImportMetadata
from google.cloud.recommendationengine_v1beta1.types.import_ import (
    ImportUserEventsRequest,
)
from google.cloud.recommendationengine_v1beta1.types.import_ import (
    ImportUserEventsResponse,
)
from google.cloud.recommendationengine_v1beta1.types.import_ import InputConfig
from google.cloud.recommendationengine_v1beta1.types.import_ import (
    UserEventImportSummary,
)
from google.cloud.recommendationengine_v1beta1.types.import_ import (
    UserEventInlineSource,
)
from google.cloud.recommendationengine_v1beta1.types.prediction_apikey_registry_service import (
    CreatePredictionApiKeyRegistrationRequest,
)
from google.cloud.recommendationengine_v1beta1.types.prediction_apikey_registry_service import (
    DeletePredictionApiKeyRegistrationRequest,
)
from google.cloud.recommendationengine_v1beta1.types.prediction_apikey_registry_service import (
    ListPredictionApiKeyRegistrationsRequest,
)
from google.cloud.recommendationengine_v1beta1.types.prediction_apikey_registry_service import (
    ListPredictionApiKeyRegistrationsResponse,
)
from google.cloud.recommendationengine_v1beta1.types.prediction_apikey_registry_service import (
    PredictionApiKeyRegistration,
)
from google.cloud.recommendationengine_v1beta1.types.prediction_service import (
    PredictRequest,
)
from google.cloud.recommendationengine_v1beta1.types.prediction_service import (
    PredictResponse,
)
from google.cloud.recommendationengine_v1beta1.types.user_event import EventDetail
from google.cloud.recommendationengine_v1beta1.types.user_event import ProductDetail
from google.cloud.recommendationengine_v1beta1.types.user_event import (
    ProductEventDetail,
)
from google.cloud.recommendationengine_v1beta1.types.user_event import (
    PurchaseTransaction,
)
from google.cloud.recommendationengine_v1beta1.types.user_event import UserEvent
from google.cloud.recommendationengine_v1beta1.types.user_event import UserInfo
from google.cloud.recommendationengine_v1beta1.types.user_event_service import (
    CollectUserEventRequest,
)
from google.cloud.recommendationengine_v1beta1.types.user_event_service import (
    ListUserEventsRequest,
)
from google.cloud.recommendationengine_v1beta1.types.user_event_service import (
    ListUserEventsResponse,
)
from google.cloud.recommendationengine_v1beta1.types.user_event_service import (
    PurgeUserEventsMetadata,
)
from google.cloud.recommendationengine_v1beta1.types.user_event_service import (
    PurgeUserEventsRequest,
)
from google.cloud.recommendationengine_v1beta1.types.user_event_service import (
    PurgeUserEventsResponse,
)
from google.cloud.recommendationengine_v1beta1.types.user_event_service import (
    WriteUserEventRequest,
)

__all__ = (
    "CatalogServiceClient",
    "CatalogServiceAsyncClient",
    "PredictionApiKeyRegistryClient",
    "PredictionApiKeyRegistryAsyncClient",
    "PredictionServiceClient",
    "PredictionServiceAsyncClient",
    "UserEventServiceClient",
    "UserEventServiceAsyncClient",
    "CatalogItem",
    "Image",
    "ProductCatalogItem",
    "CreateCatalogItemRequest",
    "DeleteCatalogItemRequest",
    "GetCatalogItemRequest",
    "ListCatalogItemsRequest",
    "ListCatalogItemsResponse",
    "UpdateCatalogItemRequest",
    "FeatureMap",
    "CatalogInlineSource",
    "GcsSource",
    "ImportCatalogItemsRequest",
    "ImportCatalogItemsResponse",
    "ImportErrorsConfig",
    "ImportMetadata",
    "ImportUserEventsRequest",
    "ImportUserEventsResponse",
    "InputConfig",
    "UserEventImportSummary",
    "UserEventInlineSource",
    "CreatePredictionApiKeyRegistrationRequest",
    "DeletePredictionApiKeyRegistrationRequest",
    "ListPredictionApiKeyRegistrationsRequest",
    "ListPredictionApiKeyRegistrationsResponse",
    "PredictionApiKeyRegistration",
    "PredictRequest",
    "PredictResponse",
    "EventDetail",
    "ProductDetail",
    "ProductEventDetail",
    "PurchaseTransaction",
    "UserEvent",
    "UserInfo",
    "CollectUserEventRequest",
    "ListUserEventsRequest",
    "ListUserEventsResponse",
    "PurgeUserEventsMetadata",
    "PurgeUserEventsRequest",
    "PurgeUserEventsResponse",
    "WriteUserEventRequest",
)



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.cloud.recommendationengine_v1beta1.types import catalog
from google.protobuf import field_mask_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.recommendationengine.v1beta1",
    manifest={
        "CreateCatalogItemRequest",
        "GetCatalogItemRequest",
        "ListCatalogItemsRequest",
        "ListCatalogItemsResponse",
        "UpdateCatalogItemRequest",
        "DeleteCatalogItemRequest",
    },
)


class CreateCatalogItemRequest(proto.Message):
    r"""Request message for CreateCatalogItem method.

    Attributes:
        parent (str):
            Required. The parent catalog resource name, such as
            ``projects/*/locations/global/catalogs/default_catalog``.
        catalog_item (google.cloud.recommendationengine_v1beta1.types.CatalogItem):
            Required. The catalog item to create.
    """

    parent = proto.Field(proto.STRING, number=1,)
    catalog_item = proto.Field(proto.MESSAGE, number=2, message=catalog.CatalogItem,)


class GetCatalogItemRequest(proto.Message):
    r"""Request message for GetCatalogItem method.

    Attributes:
        name (str):
            Required. Full resource name of catalog item, such as
            ``projects/*/locations/global/catalogs/default_catalog/catalogitems/some_catalog_item_id``.
    """

    name = proto.Field(proto.STRING, number=1,)


class ListCatalogItemsRequest(proto.Message):
    r"""Request message for ListCatalogItems method.

    Attributes:
        parent (str):
            Required. The parent catalog resource name, such as
            ``projects/*/locations/global/catalogs/default_catalog``.
        page_size (int):
            Optional. Maximum number of results to return
            per page. If zero, the service will choose a
            reasonable default.
        page_token (str):
            Optional. The previous
            ListCatalogItemsResponse.next_page_token.
        filter (str):
            Optional. A filter to apply on the list
            results.
    """

    parent = proto.Field(proto.STRING, number=1,)
    page_size = proto.Field(proto.INT32, number=2,)
    page_token = proto.Field(proto.STRING, number=3,)
    filter = proto.Field(proto.STRING, number=4,)


class ListCatalogItemsResponse(proto.Message):
    r"""Response message for ListCatalogItems method.

    Attributes:
        catalog_items (Sequence[google.cloud.recommendationengine_v1beta1.types.CatalogItem]):
            The catalog items.
        next_page_token (str):
            If empty, the list is complete. If nonempty, the token to
            pass to the next request's
            ListCatalogItemRequest.page_token.
    """

    @property
    def raw_page(self):
        return self

    catalog_items = proto.RepeatedField(
        proto.MESSAGE, number=1, message=catalog.CatalogItem,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class UpdateCatalogItemRequest(proto.Message):
    r"""Request message for UpdateCatalogItem method.

    Attributes:
        name (str):
            Required. Full resource name of catalog item, such as
            ``projects/*/locations/global/catalogs/default_catalog/catalogItems/some_catalog_item_id``
        catalog_item (google.cloud.recommendationengine_v1beta1.types.CatalogItem):
            Required. The catalog item to update/create. The
            'catalog_item_id' field has to match that in the 'name'.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Optional. Indicates which fields in the
            provided 'item' to update. If not set, will by
            default update all fields.
    """

    name = proto.Field(proto.STRING, number=1,)
    catalog_item = proto.Field(proto.MESSAGE, number=2, message=catalog.CatalogItem,)
    update_mask = proto.Field(
        proto.MESSAGE, number=3, message=field_mask_pb2.FieldMask,
    )


class DeleteCatalogItemRequest(proto.Message):
    r"""Request message for DeleteCatalogItem method.

    Attributes:
        name (str):
            Required. Full resource name of catalog item, such as
            ``projects/*/locations/global/catalogs/default_catalog/catalogItems/some_catalog_item_id``.
    """

    name = proto.Field(proto.STRING, number=1,)


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.cloud.recommendationengine_v1beta1.types import user_event as gcr_user_event
from google.protobuf import timestamp_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.recommendationengine.v1beta1",
    manifest={
        "PurgeUserEventsRequest",
        "PurgeUserEventsMetadata",
        "PurgeUserEventsResponse",
        "WriteUserEventRequest",
        "CollectUserEventRequest",
        "ListUserEventsRequest",
        "ListUserEventsResponse",
    },
)


class PurgeUserEventsRequest(proto.Message):
    r"""Request message for PurgeUserEvents method.

    Attributes:
        parent (str):
            Required. The resource name of the event_store under which
            the events are created. The format is
            ``projects/${projectId}/locations/global/catalogs/${catalogId}/eventStores/${eventStoreId}``
        filter (str):
            Required. The filter string to specify the events to be
            deleted. Empty string filter is not allowed. This filter can
            also be used with ListUserEvents API to list events that
            will be deleted. The eligible fields for filtering are:

            -  eventType - UserEvent.eventType field of type string.
            -  eventTime - in ISO 8601 "zulu" format.
            -  visitorId - field of type string. Specifying this will
               delete all events associated with a visitor.
            -  userId - field of type string. Specifying this will
               delete all events associated with a user. Example 1:
               Deleting all events in a time range.
               ``eventTime > "2012-04-23T18:25:43.511Z" eventTime < "2012-04-23T18:30:43.511Z"``
               Example 2: Deleting specific eventType in time range.
               ``eventTime > "2012-04-23T18:25:43.511Z" eventType = "detail-page-view"``
               Example 3: Deleting all events for a specific visitor
               ``visitorId = visitor1024`` The filtering fields are
               assumed to have an implicit AND.
        force (bool):
            Optional. The default value is false.
            Override this flag to true to actually perform
            the purge. If the field is not set to true, a
            sampling of events to be deleted will be
            returned.
    """

    parent = proto.Field(proto.STRING, number=1,)
    filter = proto.Field(proto.STRING, number=2,)
    force = proto.Field(proto.BOOL, number=3,)


class PurgeUserEventsMetadata(proto.Message):
    r"""Metadata related to the progress of the PurgeUserEvents
    operation. This will be returned by the
    google.longrunning.Operation.metadata field.

    Attributes:
        operation_name (str):
            The ID of the request / operation.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Operation create time.
    """

    operation_name = proto.Field(proto.STRING, number=1,)
    create_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)


class PurgeUserEventsResponse(proto.Message):
    r"""Response of the PurgeUserEventsRequest. If the long running
    operation is successfully done, then this message is returned by
    the google.longrunning.Operations.response field.

    Attributes:
        purged_events_count (int):
            The total count of events purged as a result
            of the operation.
        user_events_sample (Sequence[google.cloud.recommendationengine_v1beta1.types.UserEvent]):
            A sampling of events deleted (or will be deleted) depending
            on the ``force`` property in the request. Max of 500 items
            will be returned.
    """

    purged_events_count = proto.Field(proto.INT64, number=1,)
    user_events_sample = proto.RepeatedField(
        proto.MESSAGE, number=2, message=gcr_user_event.UserEvent,
    )


class WriteUserEventRequest(proto.Message):
    r"""Request message for WriteUserEvent method.

    Attributes:
        parent (str):
            Required. The parent eventStore resource name, such as
            ``projects/1234/locations/global/catalogs/default_catalog/eventStores/default_event_store``.
        user_event (google.cloud.recommendationengine_v1beta1.types.UserEvent):
            Required. User event to write.
    """

    parent = proto.Field(proto.STRING, number=1,)
    user_event = proto.Field(proto.MESSAGE, number=2, message=gcr_user_event.UserEvent,)


class CollectUserEventRequest(proto.Message):
    r"""Request message for CollectUserEvent method.

    Attributes:
        parent (str):
            Required. The parent eventStore name, such as
            ``projects/1234/locations/global/catalogs/default_catalog/eventStores/default_event_store``.
        user_event (str):
            Required. URL encoded UserEvent proto.
        uri (str):
            Optional. The url including cgi-parameters
            but excluding the hash fragment. The URL must be
            truncated to 1.5K bytes to conservatively be
            under the 2K bytes. This is often more useful
            than the referer url, because many browsers only
            send the domain for 3rd party requests.
        ets (int):
            Optional. The event timestamp in
            milliseconds. This prevents browser caching of
            otherwise identical get requests. The name is
            abbreviated to reduce the payload bytes.
    """

    parent = proto.Field(proto.STRING, number=1,)
    user_event = proto.Field(proto.STRING, number=2,)
    uri = proto.Field(proto.STRING, number=3,)
    ets = proto.Field(proto.INT64, number=4,)


class ListUserEventsRequest(proto.Message):
    r"""Request message for ListUserEvents method.

    Attributes:
        parent (str):
            Required. The parent eventStore resource name, such as
            ``projects/*/locations/*/catalogs/default_catalog/eventStores/default_event_store``.
        page_size (int):
            Optional. Maximum number of results to return
            per page. If zero, the service will choose a
            reasonable default.
        page_token (str):
            Optional. The previous
            ListUserEventsResponse.next_page_token.
        filter (str):
            Optional. Filtering expression to specify restrictions over
            returned events. This is a sequence of terms, where each
            term applies some kind of a restriction to the returned user
            events. Use this expression to restrict results to a
            specific time range, or filter events by eventType. eg:
            eventTime > "2012-04-23T18:25:43.511Z"
            eventsMissingCatalogItems
            eventTime<"2012-04-23T18:25:43.511Z" eventType=search

            We expect only 3 types of fields:

            ::

               * eventTime: this can be specified a maximum of 2 times, once with a
                 less than operator and once with a greater than operator. The
                 eventTime restrict should result in one contiguous valid eventTime
                 range.

               * eventType: only 1 eventType restriction can be specified.

               * eventsMissingCatalogItems: specififying this will restrict results
                 to events for which catalog items were not found in the catalog. The
                 default behavior is to return only those events for which catalog
                 items were found.

            Some examples of valid filters expressions:

            -  Example 1: eventTime > "2012-04-23T18:25:43.511Z"
               eventTime < "2012-04-23T18:30:43.511Z"
            -  Example 2: eventTime > "2012-04-23T18:25:43.511Z"
               eventType = detail-page-view
            -  Example 3: eventsMissingCatalogItems eventType = search
               eventTime < "2018-04-23T18:30:43.511Z"
            -  Example 4: eventTime > "2012-04-23T18:25:43.511Z"
            -  Example 5: eventType = search
            -  Example 6: eventsMissingCatalogItems
    """

    parent = proto.Field(proto.STRING, number=1,)
    page_size = proto.Field(proto.INT32, number=2,)
    page_token = proto.Field(proto.STRING, number=3,)
    filter = proto.Field(proto.STRING, number=4,)


class ListUserEventsResponse(proto.Message):
    r"""Response message for ListUserEvents method.

    Attributes:
        user_events (Sequence[google.cloud.recommendationengine_v1beta1.types.UserEvent]):
            The user events.
        next_page_token (str):
            If empty, the list is complete. If nonempty, the token to
            pass to the next request's ListUserEvents.page_token.
    """

    @property
    def raw_page(self):
        return self

    user_events = proto.RepeatedField(
        proto.MESSAGE, number=1, message=gcr_user_event.UserEvent,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


__all__ = tuple(sorted(__protobuf__.manifest))
